<?php

$educationLevelDifferences = [

  [
    'title' => 'Registering for School',
    'high-school-info' => [
      'Registration is only needed for Grade 9, or if the student is new to the school.',
      'There are no fees to attend high school.'
    ],
    'college-university-info' => [
      'Students must apply to college or university by completing the necessary forms. There are fees to apply.',
      'Tuition and other fees must be paid in order to register.',
      'More information <a href="/preparing-for-college-and-university/applying-to-post-secondary">here</a>'
    ]
  ],
  [
    'title' => 'Registering for Classes',
    'high-school-info' => [
      'Students choose courses in February or March for the following school year.',
      'Some classes have a limited number of spaces, so you need to register early.'
    ],
    'college-university-info' => [
      'Students must ensure they have the correct prerequisites and meet grade requirements. Many courses are only available to students in certain programs.',
      'Some classes or programs have limited student capacity, so you need to apply early and/or complete additional paperwork to be considered.'
    ]
  ],
  [
    'title' => 'Class Size',
    'high-school-info' => ['Classes are usually less than 30.'],
    'college-university-info' => [
      'College classroom sizes range from 25-150.',
      'University Class sizes range from 50-400.',
      'Class size tends to shrink as classes and years progress.',
      'Supplementary class (i.e., labs) sizes range from 15 to 60 people.'
    ]
  ],
  [
    'title' => 'Teachers',
    'high-school-info' => [
      'You see your teachers every day.',
      'Teachers are available after school if you need help.'
    ],
    'college-university-info' => [
      'You might only see your instructors one to three times a week.',
      'Instructors are usually the primary source of instruction in both lectures and labs.',
      'Generally, you must make an appointment to talk with your instructor during their office hours.',
      'Most teacher/professors will meet with you before or after class for a quick discussion.'
    ]
  ],
  [
    'title' => 'Routines',
    'high-school-info' => [
      'Students are given a schedule which is the same for most days.',
      'There are classes every day.',
      'School hours are between 8:30 a.m. to 4 p.m.'
    ],
    'college-university-info' => [
      'Students choose classes in June - July based on program requirements.',
      'Most classes are held 1 to 3 times a week.',
      'Classes are held between 8 a.m. - 10 p.m.'
    ]
  ],
  [
    'title' => 'Responsibility',
    'high-school-info' => [
      'Teachers assign work, make deadlines, and remind you of due dates.',
      'The office will call home if you are not at school. The teachers may send work home if you miss a class.',
      'If you miss an exam or test, you can write it later.'
    ],
    'college-university-info' => [
      'You must make sure your assignments are completed and handed in on time. Instructors may not remind you of due dates.',
      'Some courses do track attendance and may be a contributor to marks, however it is your responsibility to obtain any notes missed.',
      'If you think you will miss an exam or test, you must talk with your instructor. You won’t be able to write it later if you fail to make arrangements.'
    ]
  ],
  [
    'title' => 'How Clases Are Taught',
    'high-school-info' => [
      'Teachers use different methods when they teach.',
      'Often there is time during class to work on assignments and homework.'
    ],
    'college-university-info' => [
      'Instructors often lecture and there is no time for independent work during class. A lot of your learning will be done through reading (i.e., textbooks, assigned materials) and online components.',
      'Labs typically spend 50% of the time teaching and 50% of the time for practice or completion of assignments. Labs are a great time to ask questions and seek additional support from instructors. Labs are often taught by Graduate Assistants or Teaching Assistants.'
    ]
  ],
  [
    'title' => 'Individual Support',
    'high-school-info' => [
      'Education assistants and special education teachers are provided by the school.',
      'The school ensures any assessments are done.',
      'Students get an Individual Education Plan'
    ],
    'college-university-info' => [
      'Students must talk to student services to get special accommodations or supports.',
      'Students must provide assessments if necessary. If the student wants to get an assessment, they need to self-advocate by going to the student support center.',
      'Students create a Post-Secondary Learning Plan with the Student Support Centre.',
    ]
  ],
  [
    'title' => 'Assignments, Tests and Grades',
    'high-school-info' => [
      'Different kinds of assignments are given. Late assignments are usually accepted.',
      'Teachers prepare students before a test (reviews, how to write the test, how to study)',
      'Final grades are based on many assignments.'
    ],
    'college-university-info' => [
      'Read course syllabus carefully!',
      'Assignments have strict deadlines. Marks are taken off for late assignments.',
      'If you are caught plagiarizing, you will be given an automatic ZERO and can be expelled.',
      'Students are responsible for preparing for exams and tests.',
      'Exams may be written in classrooms or gyms with students from other courses.',
      'Some courses base marks on multiple assignments, lab performance and tests. Some courses will only base marks on 2-3 tests.'
    ]
  ]

];


?>

<article>

  <div class="flex flex-col bg-white">

    <div class="py-4 bg-red-500 px-6">
      <p class="font-bold text-white">DIFFERENCES BETWEEN HIGH SCHOOL AND POST-SECONDARY</p>
    </div>

    <div class="flex flex-1 flex-col gap-y-7">
      <div>

        <ul role="list" class="text-blue-900">

          <?php foreach ($educationLevelDifferences as $difference) { ?>

            <li class="accordion differences-columns">

              <div class="relative flex px-2 rounded-md justify-between">

                <div class="gap-x-3 rounded-md p-2 text-sm leading-6 font-semibold flex items-center align-middle">
                  <p class="pr-4"><?php echo $difference['title'] ?></p>
                </div>

                <button class="accordion-toggle absolute inset-0 flex w-full h-full">
                  <i class="fas fa-chevron-down items-center ml-auto rounded-m px-2.5 py-2 " aria-hidden="true"></i>
                  <i class="fas fa-times items-center ml-auto rounded-md px-3 py-2" aria-hidden="true"></i>
                </button>

              </div>

              <div class="accordion-content space-y-4">

                <!-- High School Information  -->
                <div>
                  <h3 class="font-medium underline mb-2">High School</h3>
                  <ul class="list-disc list-inside">
                    <?php
                    foreach ($difference['high-school-info'] as $info) { ?>
                      <li class="mb-2">
                        <?php echo $info ?>
                      </li>
                    <?php } ?>
                  </ul>
                </div>

                <!-- College University Information  -->
                <div>
                  <h3 class="font-medium underline mb-2">College/University</h3>
                  <ul class="list-disc list-inside">
                    <?php
                    foreach ($difference['college-university-info'] as $info) { ?>
                      <li class="mb-2">
                        <?php echo $info ?>
                      </li>
                    <?php } ?>
                  </ul>
                </div>

              </div>

            </li>

          <?php } ?>

        </ul>

      </div>
    </div>

  </div>

</article>